summaryrefslogtreecommitdiff
path: root/examples
diff options
context:
space:
mode:
authorPete Batard <pete@akeo.ie>2012-04-03 13:40:39 +0100
committerPete Batard <pete@akeo.ie>2012-04-03 15:42:10 +0100
commit791b7473ec38155ee3d1d9889f3d0f1b4c8f33f0 (patch)
tree009cb8fb6347691d69125939a399d538a21cca02 /examples
parentf98eaca0985364be00fcfde3fd3884075092a4e9 (diff)
downloadlibusb-791b7473ec38155ee3d1d9889f3d0f1b4c8f33f0.tar.gz
Misc: Rebrand to libusbx
* Mentions of 'libusb' in doxygen are changed to 'libusbx' * Also update copyright notices and remove unneeded EOF LFs
Diffstat (limited to 'examples')
-rw-r--r--examples/dpfp.c4
-rw-r--r--examples/dpfp_threaded.c4
-rw-r--r--examples/listdevs.c4
-rw-r--r--examples/xusb.c9
4 files changed, 10 insertions, 11 deletions
diff --git a/examples/dpfp.c b/examples/dpfp.c
index 1b3c3a4..7652407 100644
--- a/examples/dpfp.c
+++ b/examples/dpfp.c
@@ -1,6 +1,6 @@
/*
- * libusb example program to manipulate U.are.U 4000B fingerprint scanner.
- * Copyright (C) 2007 Daniel Drake <dsd@gentoo.org>
+ * libusbx example program to manipulate U.are.U 4000B fingerprint scanner.
+ * Copyright © 2007 Daniel Drake <dsd@gentoo.org>
*
* Basic image capture program only, does not consider the powerup quirks or
* the fact that image encryption may be enabled. Not expected to work
diff --git a/examples/dpfp_threaded.c b/examples/dpfp_threaded.c
index c3d314d..a46d885 100644
--- a/examples/dpfp_threaded.c
+++ b/examples/dpfp_threaded.c
@@ -1,6 +1,6 @@
/*
- * libusb example program to manipulate U.are.U 4000B fingerprint scanner.
- * Copyright (C) 2007 Daniel Drake <dsd@gentoo.org>
+ * libusbx example program to manipulate U.are.U 4000B fingerprint scanner.
+ * Copyright © 2007 Daniel Drake <dsd@gentoo.org>
*
* Basic image capture program only, does not consider the powerup quirks or
* the fact that image encryption may be enabled. Not expected to work
diff --git a/examples/listdevs.c b/examples/listdevs.c
index 6ab8917..df30224 100644
--- a/examples/listdevs.c
+++ b/examples/listdevs.c
@@ -1,6 +1,6 @@
/*
- * libusb example program to list devices on the bus
- * Copyright (C) 2007 Daniel Drake <dsd@gentoo.org>
+ * libusbx example program to list devices on the bus
+ * Copyright © 2007 Daniel Drake <dsd@gentoo.org>
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
diff --git a/examples/xusb.c b/examples/xusb.c
index 970458d..b1d338f 100644
--- a/examples/xusb.c
+++ b/examples/xusb.c
@@ -1,8 +1,7 @@
/*
* xusb: Generic USB test program
- * Copyright (c) 2009-2011 Pete Batard <pbatard@gmail.com>
- * Based on lsusb, copyright (c) 2007 Daniel Drake <dsd@gentoo.org>
- * With contributions to Mass Storage test by Alan Stern.
+ * Copyright © 2009-2012 Pete Batard <pete@akeo.ie>
+ * Contributions to Mass Storage by Alan Stern.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -49,7 +48,7 @@
#endif
// Future versions of libusb will use usb_interface instead of interface
// in libusb_config_descriptor => catter for that
#define usb_interface interface
@@ -862,7 +861,7 @@ int main(int argc, char** argv)
#ifdef HAS_GETVERSION
version = libusb_getversion(); */
- printf("Using libusb v%d.%d.%d.%d\n\n", version->major, version->minor, version->micro, version->nano);
+ printf("Using libusbx v%d.%d.%d.%d\n\n", version->major, version->minor, version->micro, version->nano);
#endif
r = libusb_init(NULL);
if (r < 0)
@@ -49,7 +48,7 @@
#endif
-// Future versions of libusb will use usb_interface instead of interface
+// Future versions of libusbx will use usb_interface instead of interface
// in libusb_config_descriptor => catter for that
#define usb_interface interface